@@ -1,7 +1,7 @@
 /*
  * guile-api.c - export additional Serveez functionality to Guile
  *
- * Copyright (C) 2001, 2002 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2001, 2002, 2003 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: guile-api.c,v 1.28 2002/07/17 18:34:18 ela Exp $
+ * $Id: guile-api.c,v 1.32 2003/06/01 12:57:07 ela Exp $
  *
  */
 
@@ -693,6 +693,44 @@ guile_server_listeners (SCM server)
 }
 #undef FUNC_NAME
 
+/* Returns a list of @code{#<svz-socket>} client smobs associated with
+   the given server instance @var{server} in arbitrary order, or an
+   empty list if there is no such client. */
+#define FUNC_NAME "svz:server:clients"
+static SCM
+guile_server_clients (SCM server)
+{
+  svz_server_t *xserver = NULL;
+  svz_array_t *clients;
+  svz_socket_t *sock;
+  char *str;
+  unsigned long i;
+  SCM list = SCM_EOL;
+
+  /* If the server instance name is given, try to translate it. */
+  if ((str = guile_to_string (server)) != NULL)
+    {
+      xserver = svz_server_get (str);
+      scm_c_free (str);
+    }
+  /* If the above failed it is possibly a real server smob. */
+  if (xserver == NULL)
+    {
+      CHECK_SMOB_ARG (svz_server, server, SCM_ARG1, "svz-server or string", 
+		      xserver);
+    }
+
+  /* Create a list of socket smobs for the server. */
+  if ((clients = svz_server_clients (xserver)) != NULL)
+    {
+      svz_array_foreach (clients, sock, i)
+	list = scm_cons (MAKE_SMOB (svz_socket, sock), list);
+      svz_array_destroy (clients);
+    }
+  return list;
+}
+#undef FUNC_NAME
+
 #if HAVE_GETRPCENT || HAVE_GETRPCBYNAME || HAVE_GETRPCBYNUMBER
 static SCM
 scm_return_rpcentry (struct rpcent *entry)
@@ -701,7 +739,7 @@ scm_return_rpcentry (struct rpcent *entry)
   SCM *ve;
 
   ans = scm_c_make_vector (3, SCM_UNSPECIFIED);
-  ve = SCM_VELTS (ans);
+  ve = SCM_WRITABLE_VELTS (ans);
   ve[0] = scm_makfrom0str (entry->r_name);
   ve[1] = scm_makfromstrs (-1, entry->r_aliases);
   ve[2] = scm_ulong2num ((unsigned long) entry->r_number);
@@ -745,7 +783,7 @@ scm_getrpc (SCM arg)
 
   if (!entry)
     scm_syserror_msg (FUNC_NAME, "no such rpc service ~A", 
-		      scm_listify (arg, SCM_UNDEFINED), errno);
+		      scm_list_n (arg, SCM_UNDEFINED), errno);
   return scm_return_rpcentry (entry);
 }
 #undef FUNC_NAME
@@ -822,7 +860,7 @@ scm_portmap_list (SCM address)
   do
     {
       mapping = scm_c_make_vector (4, SCM_UNSPECIFIED);
-      ve = SCM_VELTS (mapping);
+      ve = SCM_WRITABLE_VELTS (mapping);
       ve[0] = scm_ulong2num ((unsigned long) map->pml_map.pm_prog);
       ve[1] = scm_ulong2num ((unsigned long) map->pml_map.pm_vers);
       ve[2] = scm_ulong2num ((unsigned long) map->pml_map.pm_prot);
@@ -856,8 +894,8 @@ scm_portmap (SCM prognum, SCM versnum, SCM protocol, SCM port)
     {
       if (!pmap_unset (SCM_INUM (prognum), SCM_INUM (versnum)))
 	scm_syserror_msg (FUNC_NAME, "~A: pmap_unset ~A ~A",
-			  scm_listify (scm_makfrom0str (strerror (errno)),
-				       prognum, versnum, SCM_UNDEFINED), 
+			  scm_list_n (scm_makfrom0str (strerror (errno)),
+				      prognum, versnum, SCM_UNDEFINED), 
 			  errno);
     }
   else
@@ -870,9 +908,9 @@ scm_portmap (SCM prognum, SCM versnum, SCM protocol, SCM port)
       if (!pmap_set (SCM_INUM (prognum), SCM_INUM (versnum), 
 		     SCM_INUM (protocol), (unsigned short) SCM_INUM (port)))
 	scm_syserror_msg (FUNC_NAME, "~A: pmap_set ~A ~A ~A ~A",
-			  scm_listify (scm_makfrom0str (strerror (errno)),
-				       prognum, versnum, protocol, port, 
-				       SCM_UNDEFINED), errno);
+			  scm_list_n (scm_makfrom0str (strerror (errno)),
+				      prognum, versnum, protocol, port, 
+				      SCM_UNDEFINED), errno);
     }
   return SCM_UNSPECIFIED;
 }
@@ -1066,26 +1104,26 @@ guile_read_file (SCM port, SCM size)
     SCM_OUT_OF_RANGE (SCM_ARG2, size);
 
   /* Allocate necessary data. */
-  data = (unsigned char *) scm_must_malloc (len, "svz-binary-data");
+  data = (unsigned char *) scm_gc_malloc (len, "svz-binary-data");
 
   /* Read from file descriptor and evaluate return value. */
   if ((ret = read (fdes, data, len)) < 0)
     {
-      scm_must_free (data);
+      scm_gc_free (data, len, "svz-binary-data");
       scm_syserror_msg (FUNC_NAME, "~A: read ~A ~A",
-			scm_listify (scm_makfrom0str (strerror (errno)),
-				     scm_int2num (fdes), size, SCM_UNDEFINED),
+			scm_list_n (scm_makfrom0str (strerror (errno)),
+				    scm_int2num (fdes), size, SCM_UNDEFINED),
 			errno);
     }
   else if (ret == 0)
     {
-      scm_must_free (data);
+      scm_gc_free (data, len, "svz-binary-data");
       return SCM_EOF_VAL;
     }
   else if (ret != len)
     {
       data = (unsigned char *) 
-	scm_must_realloc (data, len, ret, "svz-binary-data");
+	scm_gc_realloc (data, len, ret, "svz-binary-data");
     }
 
   /* Finally return binary smob. */
@@ -1167,6 +1205,7 @@ guile_api_init (void)
   scm_c_define_gsubr ("svz:sock?", 1, 0, 0, guile_sock_p);
   scm_c_define_gsubr ("svz:server?", 1, 0, 0, guile_server_p);
   scm_c_define_gsubr ("svz:server:listeners", 1, 0, 0, guile_server_listeners);
+  scm_c_define_gsubr ("svz:server:clients", 1, 0, 0, guile_server_clients);
   scm_c_define_gsubr ("svz:sock:send-buffer", 1, 0, 0, guile_sock_send_buffer);
   scm_c_define_gsubr ("svz:sock:send-buffer-size",
 		      1, 1, 0, guile_sock_send_buffer_size);
