@@ -2,7 +2,8 @@
  * guile.c - interface to Guile core library
  *
  * Copyright (C) 2001 Raimund Jacob <raimi@lkcc.org>
- * Copyright (C) 2001, 2002 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2001, 2002, 2003 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2002 Andreas Rottmann <a.rottmann@gmx.at>
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: guile.c,v 1.68 2002/09/28 10:33:48 ela Exp $
+ * $Id: guile.c,v 1.72 2003/06/01 12:57:07 ela Exp $
  *
  */
 
@@ -72,7 +73,7 @@ static SCM guile_load_port = SCM_UNDEFINED;
  * construct a @code{svz_hash_t} from it. The values of this hash are 
  * pointers to @code{guile_value_t} structures. The @code{guile_value_t} 
  * structure contains a @code{defined} field which counts the number of 
- * occurences of the key. Use @code{optionhash_validate} to make sure it 
+ * occurrences of the key. Use @code{optionhash_validate} to make sure it 
  * is 1 for each key. The @code{use} field is to make sure that each key 
  * was needed exactly once. Use @code{optionhash_validate} again to find 
  * out which ones were not needed.
@@ -161,7 +162,7 @@ guile_error (char *format, ...)
   /* FIXME: Why is this port undefined in guile exceptions ? */
   SCM lp = guile_get_current_load_port ();
   char *file = (!SCM_UNBNDP (lp) && SCM_PORTP (lp)) ? 
-    gh_scm2newstr (SCM_FILENAME (lp), NULL) : NULL;
+    scm_c_string2str (SCM_FILENAME (lp), NULL, NULL) : NULL;
 
   /* guile counts lines from 0, we have to add one */
   fprintf (stderr, "%s:%d:%d: ", file ? file : "undefined",
@@ -251,7 +252,7 @@ optionhash_get (svz_hash_t *hash, char *key)
  * code). Some please explain the "." to Stefan and Raimi...
  */
 svz_hash_t *
-guile_to_optionhash (SCM pairlist, char *txt, int dounpack)
+guile_to_optionhash (SCM pairlist, char *suffix, int dounpack)
 {
   svz_hash_t *hash = optionhash_create ();
   guile_value_t *old_value;
@@ -271,7 +272,7 @@ guile_to_optionhash (SCM pairlist, char *txt, int dounpack)
       /* The car must be another pair which contains key and value. */
       if (!SCM_PAIRP (pair))
 	{
-	  guile_error ("Not a pair %s", txt);
+	  guile_error ("Not a pair %s", suffix);
 	  err = 1;
 	  break;
 	}
@@ -281,7 +282,7 @@ guile_to_optionhash (SCM pairlist, char *txt, int dounpack)
       if (NULL == (str = guile_to_string (key)))
 	{
 	  /* Unknown key type, must be string or symbol. */
-	  guile_error ("Key must be string or symbol %s", txt);
+	  guile_error ("Invalid key type (string expected) %s", suffix);
 	  err = 1;
 	  break;
 	}
@@ -301,7 +302,7 @@ guile_to_optionhash (SCM pairlist, char *txt, int dounpack)
   /* Pairlist must be SCM_NULLP() now or that was not a good pairlist. */
   if (!err && !SCM_NULLP (pairlist))
     {
-      guile_error ("Invalid pairlist %s", txt);
+      guile_error ("Invalid pairlist %s", suffix);
       err = 1;
     }
 
@@ -398,8 +399,9 @@ guile_to_boolean (SCM cell, int *target)
 #undef FUNC_NAME
 
 /*
- * Convert the given guile list @var{list} into a hash. Return NULL on
- * failure. Error messages will be emitted if necessary.
+ * Convert the given guile list @var{list} into a hash.  Return
+ * @code{NULL} on failure.  Error messages will be emitted if
+ * necessary. 
  */
 #define FUNC_NAME "guile_to_hash"
 svz_hash_t *
@@ -412,7 +414,7 @@ guile_to_hash (SCM list, char *prefix)
   if (!SCM_LISTP (list))
     {
       err = -1;
-      guile_error ("%s: Not a valid list for hash (alist)", prefix);
+      guile_error ("%s: Not a valid list for hash", prefix);
       return NULL;
     }
 
@@ -427,8 +429,7 @@ guile_to_hash (SCM list, char *prefix)
       if (!SCM_PAIRP (pair))
 	{
 	  err = -1;
-	  guile_error ("%s: Element #%d of hash (alist) is not a pair", 
-		       prefix, i);
+	  guile_error ("%s: Element #%d of hash is not a pair", prefix, i);
 	  continue;
 	}
       k = SCM_CAR (pair);
@@ -438,8 +439,8 @@ guile_to_hash (SCM list, char *prefix)
       if (NULL == (str = guile_to_string (k)))
 	{
 	  err = -1;
-	  guile_error ("%s: Element #%d of hash (alist) "
-		       "has no valid key (string required)", prefix, i);
+	  guile_error ("%s: Element #%d of hash has no valid key "
+		       "(string expected)", prefix, i);
 	  keystr = NULL;
 	}
       else
@@ -452,8 +453,8 @@ guile_to_hash (SCM list, char *prefix)
       if (NULL == (str = guile_to_string (v)))
 	{
 	  err = -1;
-	  guile_error ("%s: Element #%d of hash (alist) "
-		       "has no valid value (string required)", prefix, i);
+	  guile_error ("%s: Element #%d of hash has no valid value "
+		       "(string expected)", prefix, i);
 	  valstr = NULL;
 	}
       else
@@ -470,7 +471,7 @@ guile_to_hash (SCM list, char *prefix)
 	}
     }
 
-  /* Free the values, keys are freed be hash destructor. */
+  /* Free the values, keys are freed by hash destructor. */
   if (err)
     {
       svz_hash_destroy (hash);
@@ -518,12 +519,7 @@ guile_to_strarray (SCM list, char *func)
     }
 
   /* Check the size of the resulting string array. */
-  if (svz_array_size (array) == 0)
-    {
-      svz_array_destroy (array);
-      array = NULL;
-    }
-  return array;
+  return svz_array_destroy_zero (array);
 }
 #undef FUNC_NAME
 
@@ -605,7 +601,7 @@ optionhash_extract_int (svz_hash_t *hash,
 }
 
 /*
- * Exctract a string value from an option hash. Returns zero if it worked.
+ * Extract a string value from an option hash. Returns zero if it worked.
  * The memory for the string is newly allocated, no matter where it came
  * from.
  */
@@ -736,39 +732,13 @@ optionhash_cb_intarray (char *server, void *arg, char *key,
   /* Yes, start parsing it. */
   else
     {
-      int err = 0, i, val;
       svz_array_t *array;
 
-      /* Is it a valid list ? */
-      if (!SCM_LISTP (hvalue))
+      if ((array = guile_to_intarray (hvalue, key)) == NULL)
 	{
-	  guile_error ("%s: Integer array `%s' is not a valid list",
-		       server, key);
+	  guile_error ("%s: Failed to parse integer array `%s'", server, key);
 	  return SVZ_ITEM_FAILED;
 	}
-
-      /* Iterate over the list and build up the array of integers. */
-      array = svz_array_create (0, NULL);
-      for (i = 0; SCM_PAIRP (hvalue); hvalue = SCM_CDR (hvalue), i++)
-	{
-	  if (guile_to_integer (SCM_CAR (hvalue), &val))
-	    {
-	      guile_error ("%s: Invalid integer element #%d in "
-			   "integer array `%s'", server, i, key);
-	      err = -1;
-	      continue;
-	    }
-	  svz_array_add (array, SVZ_NUM2PTR (val));
-	}
-
-      if (err)
-	{
-	  /* Free the integer array so far. */
-	  svz_array_destroy (array);
-	  return SVZ_ITEM_FAILED;
-	}
-
-      /* Yippie, have it. */
       *target = array;
     }
   return SVZ_ITEM_OK;
@@ -824,41 +794,13 @@ optionhash_cb_strarray (char *server, void *arg, char *key,
     }
   else
     {
-      int err = 0, i;
       svz_array_t *array;
-      char *str;
 
-      /* Check if this is really a list. */
-      if (!SCM_LISTP (hvalue))
+      if ((array = guile_to_strarray (hvalue, key)) == NULL)
 	{
-	  guile_error ("%s: String array `%s' is not a valid list",
-		       server, key);
+	  guile_error ("%s: Failed to parse string array `%s'", server, key);
 	  return SVZ_ITEM_FAILED;
 	}
-
-      /* Iterate over the list and build up the array of strings. */
-      array = svz_array_create (0, svz_free);
-      for (i = 0; SCM_PAIRP (hvalue); hvalue = SCM_CDR (hvalue), i++)
-	{
-	  if (NULL == (str = guile_to_string (SCM_CAR (hvalue))))
-	    {
-	      guile_error ("%s: Invalid string element #%d in "
-			   "string array `%s'", server, i, key);
-	      err = -1;
-	      continue;
-	    }
-	  svz_array_add (array, svz_strdup (str));
-	  scm_c_free (str);
-	}
-
-      /* Free the string array so far. */
-      if (err)
-	{
-	  svz_array_destroy (array);
-	  return SVZ_ITEM_FAILED;
-	}
-
-      /* Okay, that's fine so far. */
       *target = array;
     }
   return SVZ_ITEM_OK;
@@ -878,87 +820,19 @@ optionhash_cb_hash (char *server, void *arg, char *key,
       if (hasdef)
 	return SVZ_ITEM_DEFAULT_ERRMSG;
 
-      guile_error ("%s: You have to define a hash (alist) called `%s'",
+      guile_error ("%s: You have to define a hash called `%s'",
 		   server, key);
       return SVZ_ITEM_FAILED;
     }
   else
     {
-      int err = 0, i;
       svz_hash_t *hash;
 
-      /* Unpack again... Whysoever. */
-      if (!SCM_LISTP (hvalue))
+      if ((hash = guile_to_hash (hvalue, key)) == NULL)
 	{
-	  err = -1;
-	  guile_error ("%s: Not a valid list for hash (alist) `%s'",
-		       server, key);
+	  guile_error ("%s: Failed to parse hash `%s'", server, key);
 	  return SVZ_ITEM_FAILED;
 	}
-
-      /* Iterate the alist. */
-      hash = svz_hash_create (7, svz_free);
-      for (i = 0; SCM_PAIRP (hvalue); hvalue = SCM_CDR (hvalue), i++)
-	{
-	  SCM k, v, pair = SCM_CAR (hvalue);
-	  char *str, *keystr, *valstr;
-
-	  if (!SCM_PAIRP (pair))
-	    {
-	      err = -1;
-	      guile_error ("%s: Element #%d of hash (alist) `%s' "
-			   "is not a pair", server, i, key);
-	      continue;
-	    }
-	  k = SCM_CAR (pair);
-	  v = SCM_CDR (pair);
-	     
-	  /* Obtain key character string. */
-	  if (NULL == (str = guile_to_string (k)))
-	    {
-	      err = -1;
-	      guile_error ("%s: Element #%d of hash (alist) `%s' "
-			   "has no valid key (string required)",
-			   server, i, key);
-	      keystr = NULL;
-	    }
-	  else
-	    {
-	      keystr = svz_strdup (str);
-	      scm_c_free (str);
-	    }
-
-	  /* Obtain value character string. */
-	  if (NULL == (str = guile_to_string (v)))
-	    {
-	      err = -1;
-	      guile_error ("%s: Element #%d of hash (alist) `%s' "
-			   "has no valid value (string required)",
-			   server, i, key);
-	      valstr = NULL;
-	    }
-	  else
-	    {
-	      valstr = svz_strdup (str);
-	      scm_c_free (str);
-	    }
-
-	  /* Add to hash if key and value look good. */
-	  if (keystr != NULL && valstr != NULL)
-	    {
-	      svz_hash_put (hash, keystr, valstr);
-	      svz_free (keystr);
-	    }
-	}
-
-      /* Free the values, keys are freed be hash destructor. */
-      if (err)
-	{
-	  svz_hash_destroy (hash);
-	  return SVZ_ITEM_FAILED;
-	}
-
-      /* We call that a hash, finally. */
       *target = hash;
     }
   return SVZ_ITEM_OK;
@@ -988,8 +862,8 @@ optionhash_cb_portcfg (char *server, void *arg, char *key,
   /* Convert Scheme cell into string. */
   if ((str = guile_to_string (hvalue)) == NULL)
     {
-      guile_error ("%s: Invalid string or symbol value for `%s'",
-		   server, key);
+      guile_error ("%s: Invalid string value for port configuration `%s' "
+		   "(string expected)", server, key);
       return SVZ_ITEM_FAILED;
     }
 
@@ -1045,6 +919,84 @@ optionhash_extract_pipe (svz_hash_t *hash,
   return err;
 }
 
+/*
+ * Instantiate a configurable type.  Takes four arguments: the name of
+ * the configurable @var{type}, the second is the type @var{name} in
+ * the configurable type's domain, the third is the @var{instance}
+ * name the newly instantiated type should get and the last is the
+ * configuration alist for the new instance.  Emits error messages (to
+ * stderr).  Returns @code{#t} when the instance was successfully
+ * created, @code{#f} in case of any error.
+ */
+#define FUNC_NAME "instantiate-config-type!"
+SCM
+guile_config_instantiate (SCM type, SCM name, SCM instance, SCM opts)
+{
+  int err = 0;
+  char *c_type = NULL, *c_name = NULL, *c_instance = NULL;
+  svz_hash_t *options = NULL;
+  char *error = NULL;
+  char *txt = NULL;
+  
+  /* Configure callbacks for the `svz_config_type_instantiate()' thing. */
+  svz_config_accessor_t accessor = {
+    optionhash_cb_before,   /* before */
+    optionhash_cb_integer,  /* integers */
+    optionhash_cb_boolean,  /* boolean */
+    optionhash_cb_intarray, /* integer arrays */
+    optionhash_cb_string,   /* strings */
+    optionhash_cb_strarray, /* string arrays */
+    optionhash_cb_hash,     /* hashes */
+    optionhash_cb_portcfg,  /* port configurations */
+    optionhash_cb_after     /* after */
+  };
+  
+  if (NULL == (c_type = guile_to_string (type)))
+    {
+      guile_error ("Invalid configurable type (string expected)");
+      FAIL ();
+    }
+  if (NULL == (c_name = guile_to_string (name)))
+    {
+      guile_error ("Invalid type identifier (string expected)");
+      FAIL ();
+    }
+  if (NULL == (c_instance = guile_to_string (instance)))
+    {
+      guile_error ("Invalid instance identifier (string expected)");
+      FAIL ();
+    }
+  
+  svz_asprintf (&txt, "defining %s `%s'", c_type, c_instance);
+
+  /* Extract options if any. */
+  if (SCM_UNBNDP (opts))
+    options = optionhash_create ();
+  else if (NULL == (options = guile_to_optionhash (opts, txt, 0)))
+    FAIL (); /* Message already emitted. */
+
+  err = svz_config_type_instantiate (c_type, c_name, c_instance,
+				     options, &accessor, &error);
+  if (err)
+    {
+      if (error)
+	guile_error ("%s", error);
+      FAIL ();
+    }
+  
+ out:
+  svz_free (txt);
+  svz_free (error);
+  scm_c_free (c_type);
+  scm_c_free (c_name);
+  scm_c_free (c_instance);
+  optionhash_destroy (options);
+
+  guile_global_error |= err;
+  return err ? SCM_BOOL_F : SCM_BOOL_T;
+}
+#undef FUNC_NAME
+
 /*
  * Guile server definition. Use two arguments:
  * First is a (unique) server name of the form "type-something" where
@@ -1057,45 +1009,21 @@ optionhash_extract_pipe (svz_hash_t *hash,
 SCM
 guile_define_server (SCM name, SCM args)
 {
+  /* Note: This function could now as well be implemented in Scheme.
+     [rotty] */
   int err = 0;
-  char *servername;
-  char *servertype = NULL, *p = NULL;
-  svz_hash_t *options = NULL;
-  svz_servertype_t *stype;
-  svz_server_t *server = NULL;
-  char *txt = NULL;
-
-  /* Configure callbacks for the `svz_server_configure()' thing. */
-  svz_server_config_t configure = {
-    optionhash_cb_before,   /* before */
-    optionhash_cb_integer,  /* integers */
-    optionhash_cb_boolean,  /* boolean */
-    optionhash_cb_intarray, /* integer arrays */
-    optionhash_cb_string,   /* strings */
-    optionhash_cb_strarray, /* string arrays */
-    optionhash_cb_hash,     /* hashes */
-    optionhash_cb_portcfg,  /* port configurations */
-    optionhash_cb_after     /* after */
-  };
-
+  char *servername = NULL, *servertype = NULL, *p = NULL;
+  SCM retval = SCM_BOOL_F;
+  
   GUILE_PRECALL ();
 
   /* Check if the given server name is valid. */
   if (NULL == (servername = guile_to_string (name)))
     {
-      guile_error ("Invalid server name");
+      guile_error (FUNC_NAME ": Invalid server name (string expected)");
       FAIL ();
     }
 
-  txt = svz_malloc (256);
-  svz_snprintf (txt, 256, "defining server `%s'", servername);
-
-  /* Extract options if any. */
-  if (SCM_UNBNDP (args))
-    options = optionhash_create ();
-  else if (NULL == (options = guile_to_optionhash (args, txt, 0)))
-    FAIL (); /* Message already emitted. */
-
   /* Separate server description. */
   p = servertype = svz_strdup (servername);
   while (*p && *p != '-')
@@ -1106,60 +1034,27 @@ guile_define_server (SCM name, SCM args)
     *p = '\0';
   else
     {
-      guile_error ("Not a valid server name: `%s'");
-      FAIL ();
-    }
-
-  /* Find the definition by lookup with dynamic loading. */
-  if (NULL == (stype = svz_servertype_get (servertype, 1)))
-    {
-      guile_error ("No such server type: `%s'", servertype);
+      guile_error (FUNC_NAME ": Not a valid server name: `%s'", servername);
       FAIL ();
     }
 
   /* Instantiate and configure this server. */
-  server = svz_server_instantiate (stype, servername);
-  server->cfg = svz_server_configure (stype,
-				      servername,
-				      (void *) options,
-				      &configure);
-  if (NULL == server->cfg && stype->prototype_size)
-    {
-      svz_server_free (server);
-      FAIL (); /* Messages emitted by callbacks. */
-    }
-
-  /* Add server if configuration is ok, no error yet. */
-  if (!err)
-    {
-      if (svz_server_get (servername) != NULL)
-	{
-	  guile_error ("Duplicate server definition: `%s'", servername);
-	  svz_server_free (server);
-	  FAIL ();
-	}
-      svz_server_add (server);
-    }
-  else
-    {
-      svz_server_free (server);
-      FAIL ();
-    }
-
+  retval = guile_config_instantiate (scm_makfrom0str ("server"),
+				     scm_makfrom0str (servertype),
+				     name, args);
  out:
-  svz_free (txt);
   svz_free (servertype);
-  scm_c_free (servername);
-  optionhash_destroy (options);
-  guile_global_error |= err;
-  return err ? SCM_BOOL_T : SCM_BOOL_F;
+  if (servername)
+    scm_c_free (servername);
+  
+  return retval;
 }
 #undef FUNC_NAME
 
 /* Validate a network port value. */
-#define GUILE_VALIDATE_PORT(port, name, proto) do {                         \
-  if ((port) < 0 || (port) > 65535) {                                       \
-    guile_error ("%s: %s port requires a short (0..65535)\n", proto, name); \
+#define GUILE_VALIDATE_PORT(port, name, proto) do {                       \
+  if ((port) < 0 || (port) > 65535) {                                     \
+    guile_error ("%s: %s port requires a short (0..65535)", proto, name); \
     err = -1; } } while (0)
 
 /*
@@ -1176,20 +1071,19 @@ guile_define_port (SCM name, SCM args)
   svz_portcfg_t *prev = NULL;
   svz_portcfg_t *cfg = svz_portcfg_create ();
   svz_hash_t *options = NULL;
-  char *portname, *proto = NULL, *txt;
+  char *portname, *proto = NULL, *txt = NULL;
 
   GUILE_PRECALL ();
 
   /* Check validity of first argument. */
   if ((portname  = guile_to_string (name)) == NULL)
     {
-      guile_error ("First argument to `" FUNC_NAME "' "
-		   "needs to be string or symbol");
+      guile_error (FUNC_NAME ": Invalid port configuration name "
+		   "(string expected)");
       FAIL ();
     }
 
-  txt = svz_malloc (256);
-  svz_snprintf (txt, 256, "defining port `%s'", portname);
+  svz_asprintf (&txt, "defining port `%s'", portname);
 
   if (NULL == (options = guile_to_optionhash (args, txt, 0)))
     FAIL (); /* Message already emitted. */
@@ -1272,7 +1166,8 @@ guile_define_port (SCM name, SCM args)
       cfg->proto = PROTO_PIPE;
 
       /* Handle receiving pipe. */
-      svz_snprintf (txt, 256, "defining pipe `%s'", PORTCFG_RECV);
+      svz_asprintf (&txt, "defining pipe `%s' in port `%s'", 
+		    PORTCFG_RECV, portname);
 
       /* Check if it is a plain string. */ 
       p = optionhash_get (options, PORTCFG_RECV);
@@ -1303,7 +1198,8 @@ guile_define_port (SCM name, SCM args)
 	}
 
       /* Try getting send pipe. */
-      svz_snprintf (txt, 256, "defining pipe `%s'", PORTCFG_SEND);
+      svz_asprintf (&txt, "defining pipe `%s' in port `%s'", 
+		    PORTCFG_SEND, portname);
 
       /* Check plain string. */
       p = optionhash_get (options, PORTCFG_SEND);
@@ -1346,7 +1242,7 @@ guile_define_port (SCM name, SCM args)
   err |= optionhash_extract_int (options, PORTCFG_RECV_BUFSIZE, 1, 0,
 				 &(cfg->recv_buffer_size), txt);
   
-  /* Aquire the connect frequency. */
+  /* Acquire the connect frequency. */
   if (cfg->proto & PROTO_TCP)
     err |= optionhash_extract_int (options, PORTCFG_FREQ, 1, 0,
 				   &(cfg->connect_freq), txt);
@@ -1355,16 +1251,29 @@ guile_define_port (SCM name, SCM args)
   if (!(cfg->proto & PROTO_PIPE))
     {
       SCM list;
+
+      cfg->deny = NULL;
       list = optionhash_get (options, PORTCFG_DENY);
       if (!SCM_EQ_P (list, SCM_UNSPECIFIED))
-	cfg->deny = guile_to_strarray (list, FUNC_NAME);
-      else
-	cfg->deny = NULL;
+	{
+	  if ((cfg->deny = guile_to_strarray (list, PORTCFG_DENY)) == NULL)
+	    {
+	      guile_error ("Failed to parse string array `" PORTCFG_DENY 
+			   "' in port `%s'", portname);
+	      err = -1;
+	    }
+	}
+      cfg->allow = NULL;
       list = optionhash_get (options, PORTCFG_ALLOW);
       if (!SCM_EQ_P (list, SCM_UNSPECIFIED))
-	cfg->allow = guile_to_strarray (list, FUNC_NAME);
-      else
-	cfg->allow = NULL;
+	{
+	  if ((cfg->allow = guile_to_strarray (list, PORTCFG_ALLOW)) == NULL)
+	    {
+	      guile_error ("Failed to parse string array `" PORTCFG_ALLOW 
+			   "' in port `%s'", portname);
+	      err = -1;
+	    }
+	}
     }
 
   svz_free (txt);
@@ -1392,7 +1301,8 @@ guile_define_port (SCM name, SCM args)
  out:
   if (err)
     svz_portcfg_destroy (cfg);
-  scm_c_free (portname);
+  if (portname)
+    scm_c_free (portname);
   optionhash_destroy (options);
   guile_global_error |= err;
   return err ? SCM_BOOL_F : SCM_BOOL_T;
@@ -1418,26 +1328,26 @@ guile_bind_server (SCM port, SCM server)
   /* Check arguments. */
   if (portname == NULL)
     {
-      guile_error ("%s: First argument must be string or symbol", FUNC_NAME);
+      guile_error ("%s: Port name must be string or symbol", FUNC_NAME);
       FAIL ();
     }
   if (servername == NULL)
     {
-      guile_error ("%s: Second argument must be string or symbol", FUNC_NAME);
+      guile_error ("%s: Server name must be string or symbol", FUNC_NAME);
       FAIL ();
     }
 
   /* Check id there is such a port configuration. */
   if ((p = svz_portcfg_get (portname)) == NULL)
     {
-      guile_error ("%s: No such port: %s", FUNC_NAME, portname);
+      guile_error ("%s: No such port: `%s'", FUNC_NAME, portname);
       err++;
     }
 
   /* Get one of the servers in the list. */
   if ((s = svz_server_get (servername)) == NULL)
     {
-      guile_error ("%s: No such server: %s", FUNC_NAME, servername);
+      guile_error ("%s: No such server: `%s'", FUNC_NAME, servername);
       err++;
     }
   
@@ -1449,8 +1359,10 @@ guile_bind_server (SCM port, SCM server)
     }
 
  out:
-  scm_c_free (portname);
-  scm_c_free (servername);
+  if (portname)
+    scm_c_free (portname);
+  if (servername)
+    scm_c_free (servername);
   guile_global_error |= err;
   return err ? SCM_BOOL_F : SCM_BOOL_T;
 }
@@ -1766,9 +1678,9 @@ guile_serveez_load (SCM file)
 
   /* Evaluate (load) file and catch exception. */
   ret = scm_internal_catch (SCM_BOOL_T,
-			    (scm_catch_body_t) guile_serveez_load_file,
+			    (scm_t_catch_body) guile_serveez_load_file,
 			    (void *) f,
-			    (scm_catch_handler_t) guile_exception,
+			    (scm_t_catch_handler) guile_exception,
 			    (void *) f);
   svz_free (f);
   return ret;
@@ -1809,6 +1721,10 @@ guile_init (void)
   /* primitive load including the loadpath */
   scm_c_define_gsubr ("serveez-load", 1, 0, 0, guile_serveez_load);
 
+  /* configurable types */
+  scm_c_define_gsubr ("instantiate-config-type!", 3, 1, 0, 
+		      guile_config_instantiate);
+  
 #if ENABLE_GUILE_SERVER
   guile_server_init ();
 #endif /* ENABLE_GUILE_SERVER */
@@ -1832,7 +1748,7 @@ guile_eval_file (void *data)
 		       !S_ISCHR (buf.st_mode) && !S_ISBLK (buf.st_mode)))
     {
       SCM ret = SCM_BOOL_F, line;
-      while (!SCM_EOF_OBJECT_P (line = scm_read (scm_def_inp)))
+      while (!SCM_EOF_OBJECT_P (line = scm_read (scm_cur_inp)))
 	ret = scm_primitive_eval_x (line);
       return SCM_BOOL_T;
     }
@@ -1853,9 +1769,9 @@ guile_load_config (char *cfgfile)
   guile_init ();
 
   ret = scm_internal_catch (SCM_BOOL_T,
-			    (scm_catch_body_t) guile_eval_file, 
+			    (scm_t_catch_body) guile_eval_file, 
 			    (void *) cfgfile, 
-			    (scm_catch_handler_t) guile_exception,
+			    (scm_t_catch_handler) guile_exception,
 			    (void *) cfgfile);
 
   if (SCM_FALSEP (ret))
