@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.  
  *
- * $Id: http-core.c,v 1.42 2001/08/03 18:09:04 ela Exp $
+ * $Id: http-core.c,v 1.44 2002/01/20 17:12:29 ela Exp $
  *
  */
 
@@ -448,6 +448,30 @@ http_set_header (char *response)
   http_header.response = response;
 }
 
+/*
+ * Check if the a content range is valid for the given file size and return
+ * zero on success, non-zero otherwise.
+ */
+int
+http_check_range (http_range_t *range, off_t filesize)
+{
+  if ((range->first <= 0) ||
+      (range->last != 0 && range->last <= range->first) ||
+      (range->last >= filesize || range->length > filesize))
+    {
+#if ENABLE_DEBUG
+      svz_log (LOG_DEBUG,
+	       "http: invalid content range (%ld-%ld/%ld not in %ld) \n",
+	       range->first, range->last, range->length, filesize);
+#endif
+      return -1;
+    }
+  return 0;
+}
+
+#define HTTP_BYTES        "bytes"
+#define HTTP_BYTES_LENGTH 5
+
 /*
  * Create a http content range if the given line specifies a valid one.
  * Return zero on success and -1 on errors.
@@ -458,24 +482,20 @@ http_get_range (char *line, http_range_t *range)
   char *p = line;
   off_t n;
 
-  /* parse until byte-range specifier */ 
+  /* check args */
   if (!line || !range)
     return -1;
-  while (*p && *p != ':')
-    p++;
-  if (!*p || *(p + 1) != ' ')
-    return -1;
-  p += 2;
 
   /* check identifier */
-  if (memcmp (p, "bytes", 5))
+  if (strlen (p) >= HTTP_BYTES_LENGTH && 
+      memcmp (p, HTTP_BYTES, HTTP_BYTES_LENGTH))
     {
 #if ENABLE_DEBUG
       svz_log (LOG_DEBUG, "http: invalid byte-range specifier (%s)\n", p);
 #endif
       return -1;
     }
-  p += 5;
+  p += HTTP_BYTES_LENGTH;
 
   /* parse content range itself */
   range->first = range->last = range->length = 0;
@@ -915,11 +935,10 @@ http_read_types (http_config_t *cfg)
   char *p, *end;
   char *content;
   char *suffix;
-  char *content_type;
 
   /* create the content type hash table if necessary */
   if (cfg->types == NULL)
-    cfg->types = svz_hash_create (4);
+    cfg->types = svz_hash_create (4, svz_free);
 
   /* try open the file */
   if ((f = svz_fopen (cfg->type_file, "rt")) == NULL)
@@ -967,11 +986,7 @@ http_read_types (http_config_t *cfg)
 	       * contain it already
 	       */
 	      if (!svz_hash_get (cfg->types, suffix))
-		{
-		  content_type = svz_malloc (strlen (content) + 1);
-		  strcpy (content_type, content);
-		  svz_hash_put (cfg->types, suffix, content_type);
-		}
+		svz_hash_put (cfg->types, suffix, svz_strdup (content));
 	    }
 	}
     }
