@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: passthrough.h,v 1.8 2001/11/22 17:17:51 ela Exp $
+ * $Id: passthrough.h,v 1.12 2001/12/19 23:15:07 ela Exp $
  *
  */
 
@@ -68,35 +68,56 @@ svz_process_t;
 #define SVZ_PROCESS_NONE  ((char *) 0L)
 #define SVZ_PROCESS_OWNER ((char *) ~0L)
 
+/* Envrionment variables used to pass the receive and send sockets to
+   the child process on Win32. */
+#define SVZ_PROCESS_RECV_HANDLE "RECV_HANDLE"
+#define SVZ_PROCESS_SEND_HANDLE "SEND_HANDLE"
+
+/* Extern declaration of the process environment pointer. */
+#if !defined(__MINGW32__) && !defined(__CYGWIN__)
+extern char **environ;
+#endif
+
+/* 
+ * This macro must be called once after @code{svz_boot()} for setting up the
+ * @code{svz_environ} variable. It simply passes the @code{environ} variable
+ * of the calling application to the underlying Serveez core API. This is
+ * necessary to make the @code{svz_envblock_default()} function working 
+ * correctly.
+ */
+#define svz_envblock_setup() do { svz_environ = environ; } while (0)
+
 __BEGIN_DECLS
 
-SERVEEZ_API int svz_sock_process __P ((svz_socket_t *, char *, char *, 
-				       char **, svz_envblock_t *, int, 
-				       char *));
+SERVEEZ_API int svz_sock_process __PARAMS ((svz_socket_t *, char *, char *, 
+					    char **, svz_envblock_t *, int, 
+					    char *));
 
-SERVEEZ_API int svz_process_disconnect __P ((svz_socket_t *));
-SERVEEZ_API int svz_process_disconnect_passthrough __P ((svz_socket_t *));
-SERVEEZ_API int svz_process_check_request __P ((svz_socket_t *));
-SERVEEZ_API int svz_process_idle __P ((svz_socket_t *));
-SERVEEZ_API int svz_process_send_pipe __P ((svz_socket_t *));
-SERVEEZ_API int svz_process_recv_pipe __P ((svz_socket_t *));
-SERVEEZ_API int svz_process_send_socket __P ((svz_socket_t *));
-SERVEEZ_API int svz_process_recv_socket __P ((svz_socket_t *));
+SERVEEZ_API int svz_process_disconnect __PARAMS ((svz_socket_t *));
+SERVEEZ_API int svz_process_disconnect_passthrough __PARAMS ((svz_socket_t *));
+SERVEEZ_API int svz_process_check_request __PARAMS ((svz_socket_t *));
+SERVEEZ_API int svz_process_idle __PARAMS ((svz_socket_t *));
+SERVEEZ_API int svz_process_send_pipe __PARAMS ((svz_socket_t *));
+SERVEEZ_API int svz_process_recv_pipe __PARAMS ((svz_socket_t *));
+SERVEEZ_API int svz_process_send_socket __PARAMS ((svz_socket_t *));
+SERVEEZ_API int svz_process_recv_socket __PARAMS ((svz_socket_t *));
 
-SERVEEZ_API int svz_process_create_child __P ((svz_process_t *));
-SERVEEZ_API int svz_process_shuffle __P ((svz_process_t *));
-SERVEEZ_API int svz_process_fork __P ((svz_process_t *));
+SERVEEZ_API int svz_process_create_child __PARAMS ((svz_process_t *));
+SERVEEZ_API int svz_process_shuffle __PARAMS ((svz_process_t *));
+SERVEEZ_API int svz_process_fork __PARAMS ((svz_process_t *));
 
-SERVEEZ_API int svz_process_check_executable __P ((char *, char **));
-SERVEEZ_API int svz_process_split_usergroup __P ((char *, char **, char **));
-SERVEEZ_API int svz_process_check_access __P ((char *, char *));
+SERVEEZ_API int svz_process_check_executable __PARAMS ((char *, char **));
+SERVEEZ_API int svz_process_split_usergroup __PARAMS ((char *, char **, 
+						       char **));
+SERVEEZ_API int svz_process_check_access __PARAMS ((char *, char *));
 
-SERVEEZ_API svz_envblock_t *svz_envblock_create __P ((void));
-SERVEEZ_API int svz_envblock_default __P ((svz_envblock_t *));
-SERVEEZ_API int svz_envblock_add __P ((svz_envblock_t *, char *, ...));
-SERVEEZ_API int svz_envblock_free __P ((svz_envblock_t *));
-SERVEEZ_API void svz_envblock_destroy __P ((svz_envblock_t *));
-SERVEEZ_API svz_envp_t svz_envblock_get __P ((svz_envblock_t *));
+SERVEEZ_API char **svz_environ;
+SERVEEZ_API svz_envblock_t *svz_envblock_create __PARAMS ((void));
+SERVEEZ_API int svz_envblock_default __PARAMS ((svz_envblock_t *));
+SERVEEZ_API int svz_envblock_add __PARAMS ((svz_envblock_t *, char *, ...));
+SERVEEZ_API int svz_envblock_free __PARAMS ((svz_envblock_t *));
+SERVEEZ_API void svz_envblock_destroy __PARAMS ((svz_envblock_t *));
+SERVEEZ_API svz_envp_t svz_envblock_get __PARAMS ((svz_envblock_t *));
 
 __END_DECLS
 
