@@ -1,7 +1,7 @@
 /*
  * socket.c - socket management implementation
  *
- * Copyright (C) 2000, 2001 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2000, 2001, 2002 Stefan Jahn <stefan@lkcc.org>
  * Copyright (C) 1999 Martin Grabmueller <mgrabmue@cs.tu-berlin.de>
  *
  * This is free software; you can redistribute it and/or modify it
@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: socket.c,v 1.21 2001/12/15 02:47:38 ela Exp $
+ * $Id: socket.c,v 1.23 2002/06/06 20:04:51 ela Exp $
  *
  */
 
@@ -160,6 +160,12 @@ svz_sock_detect_proto (svz_socket_t *sock)
 	    return -1;
 	  if (server->connect_socket (server, sock))
 	    return -1;
+	  if (sock->check_request == svz_sock_detect_proto)
+	    {
+	      svz_log (LOG_ERROR, "%s: check-request callback unchanged\n", 
+		       server->type->prefix);
+	      sock->check_request = NULL;
+	    }
 	  if (sock->check_request)
 	    return sock->check_request (sock);
 	  return 0;
@@ -377,6 +383,7 @@ svz_sock_alloc (void)
   sock->pid = INVALID_HANDLE;
 
   sock->read_socket = svz_tcp_read_socket;
+  sock->read_socket_oob = svz_tcp_recv_oob;
   sock->write_socket = svz_tcp_write_socket;
   sock->check_request = svz_sock_detect_proto;
   sock->disconnected_socket = svz_sock_default_disconnect;
