@@ -1,7 +1,7 @@
 /*
  * tcp-socket.c - TCP socket connection implementation
  *
- * Copyright (C) 2000, 2001 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2000, 2001, 2002 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.  
  *
- * $Id: tcp-socket.c,v 1.10 2001/10/31 22:51:10 ela Exp $
+ * $Id: tcp-socket.c,v 1.16 2002/06/09 10:13:09 ela Exp $
  *
  */
 
@@ -43,6 +43,10 @@
 # include <sys/time.h>
 #endif
 
+#if HAVE_SYS_IOCTL_H
+# include <sys/ioctl.h>
+#endif
+
 #ifdef __MINGW32__
 # include <winsock2.h>
 #endif
@@ -189,7 +193,7 @@ svz_tcp_read_socket (svz_socket_t *sock)
 	    return ret;
 	}
     }
-  /* The socket was `select ()'ed but there is no data. */
+  /* The socket was `select()'ed but there is no data. */
   else
     {
       svz_log (LOG_ERROR, "tcp: recv: no data on socket %d\n", desc);
@@ -199,6 +203,88 @@ svz_tcp_read_socket (svz_socket_t *sock)
   return 0;
 }
 
+/*
+ * This function is the default @code{read_socket_oob()} callback for
+ * TCP sockets.  It stores the received out-of-band data (a single byte 
+ * only) in @code{sock->oob} and runs the @code{check_request_oob()} callback 
+ * if it is set properly.  Returns -1 on failure and zero otherwise.  The
+ * function does not do anything if the underlying operating system does not
+ * support urgent data and simply returns -1.
+ */
+int
+svz_tcp_recv_oob (svz_socket_t *sock)
+{
+#ifdef MSG_OOB
+  SOCKET desc = sock->sock_desc;
+  int num_read, ret;
+
+#if 0
+#if HAVE_POLL && ENABLE_POLL && defined (__linux__)
+#ifdef SIOCATMARK
+  /* FIXME: fails for poll() on GNU/Linux ???  This is a hack !!! 
+            With this hack you are missing some OOB data bytes if sent too
+            frequently.  It is *not* necessary for `select()'.  Don't ask. 
+            The symptom is: `recv(..., MSG_OOB)' return `EINVAL'.  */
+  ret = ioctl (desc, SIOCATMARK, &num_read);
+  if (ret != -1 && num_read == 0)
+    {
+      svz_log (LOG_FATAL, "cannot read OOB data byte\n");
+      num_read = 0;
+    }
+  else
+#endif /* SIOCATMARK */
+#endif /* HAVE_POLL && ENABLE_POLL && linux */
+#endif
+
+  num_read = recv (desc, (void *) &sock->oob, 1, MSG_OOB);
+  if (num_read < 0)
+    {
+      svz_log (LOG_ERROR, "tcp: recv-oob: %s\n", NET_ERROR);
+      return -1;
+    }
+  else if (num_read > 0)
+    {
+      if (sock->check_request_oob)
+	if ((ret = sock->check_request_oob (sock)) != 0)
+	  return ret;
+    }
+  return 0;
+#else /* not MSG_OOB */
+  return -1;
+#endif /* not MSG_OOB */
+}
+
+/*
+ * If the underlying operating system supports urgent data (out-of-band) in
+ * TCP streams this function tries to send the byte in @code{sock->oob} 
+ * through the socket structure @var{sock} as out-of-band data.  The function
+ * returns zero on success and -1 otherwise (also if urgent data is not 
+ * supported).
+ */
+int
+svz_tcp_send_oob (svz_socket_t *sock)
+{
+#ifdef MSG_OOB
+  SOCKET desc = sock->sock_desc;
+  int num_written;
+
+  num_written = send (desc, (void *) &sock->oob, 1, MSG_OOB);
+  if (num_written < 0)
+    {
+      svz_log (LOG_ERROR, "tcp: send-oob: %s\n", NET_ERROR);
+      return -1;
+    }
+  else if (num_written == 0)
+    {
+      svz_log (LOG_ERROR, "tcp: send-oob: unable to send `0x%02x'\n", 
+	       sock->oob);
+    }
+  return 0;
+#else /* not MSG_OOB */
+  return -1;
+#endif /* not MSG_OOB */
+}
+
 /*
  * Create a TCP connection to host @var{host} and set the socket descriptor
  * in structure @var{sock} to the resulting socket. Return a zero value on 
@@ -230,6 +316,7 @@ svz_tcp_connect (unsigned long host, unsigned short port)
   sock->proto = PROTO_TCP;
   sock->flags |= (SOCK_FLAG_SOCK | SOCK_FLAG_CONNECTING);
   sock->connected_socket = svz_tcp_default_connect;
+  sock->check_request = NULL;
   svz_sock_enqueue (sock);
 
   return sock;
