@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.  
  *
- * $Id: nut-request.h,v 1.3 2001/05/19 23:04:58 ela Exp $
+ * $Id: nut-request.h,v 1.4 2001/08/01 10:16:23 ela Exp $
  *
  */
 
@@ -30,10 +30,11 @@
 #endif
 
 /* Exported functions. */
-int nut_reply (svz_socket_t *sock, nut_header_t *hdr, byte *packet);
-int nut_push_request (svz_socket_t *sock, nut_header_t *hdr, byte *packet);
-int nut_query (svz_socket_t *sock, nut_header_t *hdr, byte *packet);
-int nut_pong (svz_socket_t *sock, nut_header_t *hdr, byte *packet);
-int nut_ping (svz_socket_t *sock, nut_header_t *hdr, byte *null);
+int nut_reply (svz_socket_t *sock, nut_header_t *hdr, svz_uint8_t *packet);
+int nut_push_request (svz_socket_t *sock, nut_header_t *hdr, 
+		      svz_uint8_t *packet);
+int nut_query (svz_socket_t *sock, nut_header_t *hdr, svz_uint8_t *packet);
+int nut_pong (svz_socket_t *sock, nut_header_t *hdr, svz_uint8_t *packet);
+int nut_ping (svz_socket_t *sock, nut_header_t *hdr, svz_uint8_t *null);
 
 #endif /* not __NUT_REQUEST_H__ */
