@@ -1,7 +1,7 @@
 /*
  * test/test.c - test suite utility functions
  *
- * Copyright (C) 2000, 2001 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2000, 2001, 2002 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: test.c,v 1.5 2001/07/03 20:02:43 ela Exp $
+ * $Id: test.c,v 1.6 2002/07/23 16:39:56 ela Exp $
  *
  */
 
@@ -57,7 +57,7 @@ test_string (void)
 unsigned long
 test_value (unsigned long nr)
 {
-  return (rand () % nr);
+  return nr ? (rand () % nr) : 0;
 }
 
 /* Print any text. */
